@@ -1,8 +1,9 @@
 from .drop_oldest_duplicate_transformer import (  # noqa: F401
     DropOldestDuplicatesTransformer,
 )
-from .dropColumnsTransformer import DropColumnsTransformer  # noqa: F401
-from .selectColumnsTransformer import SelectColumnsTransformer  # noqa: F401
+from .dropColumnsTransformer_nc import DropColumnsTransformerNC  # noqa: F401
+from .join_dataframes_transformer import JoinDataframesTransformerNC  # noqa: F401
+from .selectColumnsTransformer_nc import SelectColumnsTransformerNC  # noqa: F401
 from .simple_sql_transformer import SimpleSqlServerTransformer  # noqa: F401
 from .timezone_transformer_nc import TimeZoneTransformerNC  # noqa: F401
 from .union_transformer import UnionTransformer  # noqa: F401
